Basis functions
===============

.. autoclass:: splinebox.basis_functions.BasisFunction
   :members:
   :undoc-members:

.. autoclass:: splinebox.basis_functions.B1

.. plot:: pyplots/plot_b1.py

.. autoclass:: splinebox.basis_functions.B2

.. plot:: pyplots/plot_b2.py

.. autoclass:: splinebox.basis_functions.B3

.. plot:: pyplots/plot_b3.py

.. autoclass:: splinebox.basis_functions.Exponential

.. plot:: pyplots/plot_exponential.py

.. autoclass:: splinebox.basis_functions.CatmullRom

.. plot:: pyplots/plot_catmullrom.py

.. autoclass:: splinebox.basis_functions.CubicHermite

.. plot:: pyplots/plot_cubichermite.py

.. autoclass:: splinebox.basis_functions.ExponentialHermite

.. plot:: pyplots/plot_exponentialhermite.py
